pub struct GeometryProbeChar {
pub index: i32,
pub unicode: u32,
pub text: Option<String>,
pub parser_action: String,
pub char_box: Option<QRect>,
pub loose_char_box: Option<QRect>,
pub char_origin: Option<[i64; 2]>,
pub font_id: Option<String>,
pub font_flags: Option<u32>,
pub font_size_q: Option<i64>,
}Expand description
Per-character geometry probe record.
Fields
index: i32Zero-based PDFium character index.
unicode: u32Unicode scalar value reported by PDFium.
text: Option<String>Character as a string when it is a valid scalar value.
parser_action: StringWhy this character would break or be skipped by the parser run builder.
char_box: Option<QRect>Current parser-critical FPDFText_GetCharBox geometry.
loose_char_box: Option<QRect>FPDFText_GetLooseCharBox geometry when the symbol is present.
char_origin: Option<[i64; 2]>FPDFText_GetCharOrigin point when the symbol is present.
font_id: Option<String>Deterministic font id used by the parser.
font_flags: Option<u32>PDFium font descriptor flags used by the parser.
font_size_q: Option<i64>Quantized font size used by the parser.